@@ -12,10 +12,10 @@ from ..models.relative_timing_create import RelativeTimingCreate
 class LayerCreate(base_model.BaseModel):
     """Schema for layer create requests."""
 
-    object_: Literal["Edge"] = Field(..., alias="object")
-    type: Literal["Layer"]
     upstream_node: str
     order: int
+    object_: Optional[Literal["Edge"]] = Field("Edge", alias="object")
+    type: Optional[Literal["Layer"]] = "Layer"
     output_index: Optional[int] = 0
     label_indexer: Optional[Union[List[Union[int, str, List[Any]]], List[Any], int, str]] = None
     start_timing: Optional[Union[AbsoluteTimingCreate, RelativeTimingCreate]] = None
