@@ -6,6 +6,7 @@ from typing_extensions import Literal
 from myst.models import base_model
 
 from ..models.absolute_timing_create import AbsoluteTimingCreate
+from ..models.cron_timing_create import CronTimingCreate
 from ..models.relative_timing_create import RelativeTimingCreate
 
 
@@ -13,8 +14,8 @@ class ModelFitPolicyCreate(base_model.BaseModel):
     """Schema for model fit policy create requests."""
 
     object_: Literal["Policy"] = Field(..., alias="object")
-    type: Literal["ModelFitPolicy"]
-    schedule_timing: Union[AbsoluteTimingCreate, RelativeTimingCreate]
+    schedule_timing: Union[AbsoluteTimingCreate, RelativeTimingCreate, CronTimingCreate]
     start_timing: Union[AbsoluteTimingCreate, RelativeTimingCreate]
     end_timing: Union[AbsoluteTimingCreate, RelativeTimingCreate]
+    type: Optional[Literal["ModelFitPolicy"]] = "ModelFitPolicy"
     active: Optional[bool] = True
