@@ -6,6 +6,7 @@ from typing_extensions import Literal
 from myst.models import base_model
 
 from ..models.absolute_timing_create import AbsoluteTimingCreate
+from ..models.cron_timing_create import CronTimingCreate
 from ..models.relative_timing_create import RelativeTimingCreate
 
 
@@ -18,7 +19,7 @@ class ModelFitPolicyUpdate(base_model.BaseModel):
     update_time: Optional[str] = None
     type: Optional[Literal["ModelFitPolicy"]] = None
     creator: Optional[str] = None
-    schedule_timing: Optional[Union[AbsoluteTimingCreate, RelativeTimingCreate]] = None
+    schedule_timing: Optional[Union[AbsoluteTimingCreate, RelativeTimingCreate, CronTimingCreate]] = None
     active: Optional[bool] = None
     node: Optional[str] = None
     start_timing: Optional[Union[AbsoluteTimingCreate, RelativeTimingCreate]] = None
