@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import Any, Optional
 
 from pydantic import Field
 from typing_extensions import Literal
@@ -15,4 +15,5 @@ class OperationConnectorGet(base_model.BaseModel):
     title: str
     provider: str
     description: str
+    parameters_schema: Any
     icon_url: Optional[str] = None
