@@ -9,10 +9,10 @@ from myst.models import base_model
 class SourceCreate(base_model.BaseModel):
     """Schema for source create requests."""
 
-    object_: Literal["Node"] = Field(..., alias="object")
-    type: Literal["Source"]
     title: str
     project: str
     connector_uuid: str
+    object_: Optional[Literal["Node"]] = Field("Node", alias="object")
+    type: Optional[Literal["Source"]] = "Source"
     description: Optional[str] = None
     parameters: Optional[Any] = None
