@@ -1,4 +1,4 @@
-from typing import Any, Optional
+from typing import Any, List, Optional
 
 from pydantic import Field
 from typing_extensions import Literal
@@ -6,6 +6,7 @@ from typing_extensions import Literal
 from myst.models import base_model
 
 from ..models.deploy_status import DeployStatus
+from ..models.time_dataset_spec import TimeDatasetSpec
 
 
 class SourceGet(base_model.BaseModel):
@@ -25,3 +26,4 @@ class SourceGet(base_model.BaseModel):
     parameters: Any
     update_time: Optional[str] = None
     description: Optional[str] = None
+    output_specs: Optional[List[TimeDatasetSpec]] = None
