@@ -1,23 +1,28 @@
-from typing import TYPE_CHECKING, List, Optional
+from typing import TYPE_CHECKING, List, Optional, Union
 
 from myst import get_client
+from myst.adapters.timing import to_timing_create
 from myst.core.data.time_array import TimeArray
 from myst.core.time.time import Time
 from myst.core.time.time_delta import TimeDelta
 from myst.models.time_dataset import TimeDataset, TimeDatasetRow
-from myst.models.timing import Timing
+from myst.models.timing import ScheduleTiming, TimeRangeBoundary, from_schedule_specifier, from_time_range_boundary
 from myst.models.types import AxisLabels, CoordinateLabels, ItemOrSlice, Shape, UUIDOrStr, to_uuid
 from myst.openapi.api.time_series import (
     create_time_series,
+    create_time_series_run_policy,
     get_time_series,
     insert_time_series_data,
     list_time_series_layers,
+    list_time_series_run_policies,
     query_time_series_data,
 )
 from myst.openapi.models.time_series_create import TimeSeriesCreate
 from myst.openapi.models.time_series_insert import TimeSeriesInsert
+from myst.openapi.models.time_series_run_policy_create import TimeSeriesRunPolicyCreate
 from myst.resources.layer import Layer
 from myst.resources.node import Node
+from myst.resources.policy import TimeSeriesRunPolicy
 
 if TYPE_CHECKING:  # Avoid circular imports.
     from myst.resources.project import Project
@@ -123,32 +128,47 @@ class TimeSeries(Node):
             client=get_client(), uuid=str(self.uuid), json_body=TimeSeriesInsert(time_dataset=time_dataset)
         )
 
-    def query_time_array(self, start_time: Time, end_time: Time, as_of_time: Optional[Time] = None) -> TimeArray:
+    def query_time_array(
+        self,
+        start_time: Time,
+        end_time: Time,
+        as_of_time: Optional[Time] = None,
+        as_of_offset: Optional[TimeDelta] = None,
+    ) -> TimeArray:
         """Queries this time series for data according to the given parameters.
 
+        At most one of `as_of_time` and `as_of_offset` may be specified. If `as_of_time` is specified, the query will
+        return data as of that particular time. If `as_of_offset` is specified, the query will return data for a
+        constant offset between the "natural" time and the as of time. If neither is specified, the API assumes an
+        `as_of_time` of now.
+
         Args:
             start_time: the beginning of the natural time range to query over, inclusive
             end_time: the end of the natural time range to query over, exclusive
             as_of_time: the precise as of time to query
+            as_of_offset: the offset from as of time to query by, where as_of_offset = natural_time - as_of_time
 
         Returns:
             a time array containing data for the specified time range and as of time
+
+        Raises:
+            ValueError: if both `as_of_time` and `as_of_offset` are specified
         """
+        if as_of_time and as_of_offset:
+            raise ValueError("At most one of `as_of_time` and `as_of_offset` may be specified.")
+
         time_series_query_result_get = query_time_series_data.request_sync(
             client=get_client(),
             uuid=str(self.uuid),
             start_time=start_time.to_iso_string(),
             end_time=end_time.to_iso_string(),
-            as_of_time=(as_of_time and as_of_time.to_iso_string()) or None,
+            as_of_time=as_of_time and as_of_time.to_iso_string(),
+            as_of_offset=as_of_offset and as_of_offset.to_iso_string(),
         )
 
-        time_arrays = TimeDataset.parse_obj(time_series_query_result_get.time_dataset).to_time_arrays()
+        time_dataset = TimeDataset.parse_obj(time_series_query_result_get.time_dataset)
 
-        # Without offering the user the ability to control flattening behavior, we just throw up our hands instead.
-        if len(time_arrays) != 1:
-            raise NotImplementedError()
-
-        return time_arrays[0]
+        return time_dataset.flatten()
 
     def create_layer(
         self,
@@ -156,8 +176,8 @@ class TimeSeries(Node):
         order: int,
         output_index: int = 0,
         label_indexer: Optional[ItemOrSlice] = None,
-        start_timing: Optional[Timing] = None,
-        end_timing: Optional[Timing] = None,
+        start_timing: Optional[TimeRangeBoundary] = None,
+        end_timing: Optional[TimeRangeBoundary] = None,
     ) -> Layer:
         """Creates a layer into this time series.
 
@@ -195,3 +215,35 @@ class TimeSeries(Node):
 
         # The API returns the layers ordered by create time, descending. We prefer explicit layer ordering here.
         return sorted(unsorted_layers, key=lambda layer: layer.order)
+
+    def create_run_policy(
+        self,
+        schedule_timing: Union[Time, TimeDelta, ScheduleTiming],
+        start_timing: Optional[TimeRangeBoundary] = None,
+        end_timing: Optional[TimeRangeBoundary] = None,
+        active: bool = True,
+    ) -> TimeSeriesRunPolicy:
+        time_series_run_policy_create = TimeSeriesRunPolicyCreate(
+            object="Policy",
+            type="TimeSeriesRunPolicy",
+            schedule_timing=to_timing_create(from_schedule_specifier(schedule_timing)),
+            start_timing=to_timing_create(from_time_range_boundary(start_timing)),
+            end_timing=to_timing_create(from_time_range_boundary(end_timing)),
+            active=active,
+        )
+
+        time_series_run_policy = create_time_series_run_policy.request_sync(
+            client=get_client(), time_series_uuid=str(self.uuid), json_body=time_series_run_policy_create
+        )
+
+        return TimeSeriesRunPolicy.parse_obj(time_series_run_policy.dict())
+
+    def list_run_policies(self) -> List[TimeSeriesRunPolicy]:
+        time_series_run_policies = list_time_series_run_policies.request_sync(
+            client=get_client(), time_series_uuid=str(self.uuid)
+        )
+
+        return [
+            TimeSeriesRunPolicy.parse_obj(time_series_run_policy.dict())
+            for time_series_run_policy in time_series_run_policies.data
+        ]
